@@ -46,7 +46,7 @@ if TYPE_CHECKING:
         StaticFilesConfig,
         TemplateConfig,
     )
-    from starlite.datastructures.provide import Provide
+    from starlite.datastructures import CacheControlHeader, ETag, Provide
     from starlite.handlers.base import BaseRouteHandler
     from starlite.plugins.base import PluginProtocol
     from starlite.routes.base import PathParameterDefinition
@@ -171,11 +171,13 @@ class Starlite(Router):
         before_shutdown: Optional["SingleOrList[LifeSpanHookHandler]"] = None,
         before_startup: Optional["SingleOrList[LifeSpanHookHandler]"] = None,
         cache_config: CacheConfig = DEFAULT_CACHE_CONFIG,
+        cache_control: Optional["CacheControlHeader"] = None,
         compression_config: Optional["CompressionConfig"] = None,
         cors_config: Optional["CORSConfig"] = None,
         csrf_config: Optional["CSRFConfig"] = None,
         debug: bool = False,
         dependencies: Optional[Dict[str, "Provide"]] = None,
+        etag: Optional["ETag"] = None,
         exception_handlers: Optional["ExceptionHandlersMap"] = None,
         guards: Optional[List["Guard"]] = None,
         logging_config: Optional["BaseLoggingConfig"] = None,
@@ -231,12 +233,17 @@ class Starlite(Router):
                 list thereof. This hook is called during the ASGI startup, before any callables in the 'on_startup'
                 list have been called.
             cache_config: Configures caching behavior of the application.
+            cache_control: A `cache-control` header of type
+                [CacheControlHeader][starlite.datastructures.CacheControlHeader] to add to route handlers of this app.
+                Can be overridden by route handlers.
             compression_config: Configures compression behaviour of the application, this enabled a builtin or user
                 defined Compression middleware.
             cors_config: If set this enables the builtin CORS middleware.
             csrf_config: If set this enables the builtin CSRF middleware.
             debug: If `True`, app errors rendered as HTML with a stack trace.
             dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            etag: An `etag` header of type [ETag][starlite.datastructures.ETag] to add to route handlers of this app.
+                Can be overridden by route handlers.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             logging_config: A subclass of [BaseLoggingConfig][starlite.config.logging.BaseLoggingConfig].
@@ -295,11 +302,13 @@ class Starlite(Router):
             before_shutdown=before_shutdown or [],
             before_startup=before_startup or [],
             cache_config=cache_config,
+            cache_control=cache_control,
             compression_config=compression_config,
             cors_config=cors_config,
             csrf_config=csrf_config,
             debug=debug,
             dependencies=dependencies or {},
+            etag=etag,
             exception_handlers=exception_handlers or {},
             guards=guards or [],
             logging_config=logging_config,
@@ -349,7 +358,9 @@ class Starlite(Router):
             after_request=config.after_request,
             after_response=config.after_response,
             before_request=config.before_request,
+            cache_control=config.cache_control,
             dependencies=config.dependencies,
+            etag=config.etag,
             exception_handlers=config.exception_handlers,
             guards=config.guards,
             middleware=config.middleware,
@@ -603,8 +614,6 @@ class Starlite(Router):
             asgi_handler = TrustedHostMiddleware(app=asgi_handler, allowed_hosts=self.allowed_hosts)  # type: ignore
         if self.cors_config:
             asgi_handler = CORSMiddleware(app=asgi_handler, **self.cors_config.dict())  # type: ignore
-        if self.csrf_config:
-            asgi_handler = CSRFMiddleware(app=asgi_handler, config=self.csrf_config)
         return self._wrap_in_exception_handler(asgi_handler, exception_handlers=self.exception_handlers or {})
 
     def _wrap_in_exception_handler(self, app: "ASGIApp", exception_handlers: "ExceptionHandlersMap") -> "ASGIApp":
@@ -749,6 +758,9 @@ class Starlite(Router):
             app=route.handle, exception_handlers=route_handler.resolve_exception_handlers()  # type: ignore[arg-type]
         )
 
+        if self.csrf_config:
+            asgi_handler = CSRFMiddleware(app=asgi_handler, config=self.csrf_config)
+
         for middleware in route_handler.resolve_middleware():
             if isinstance(middleware, StarletteMiddleware):
                 handler, kwargs = middleware
