@@ -24,8 +24,8 @@ from starlette.status import (
 )
 
 from starlite.constants import REDIRECT_STATUS_CODES
+from starlite.datastructures import CacheControlHeader, ETag, Provide, ResponseHeader
 from starlite.datastructures.background_tasks import BackgroundTask, BackgroundTasks
-from starlite.datastructures.provide import Provide
 from starlite.datastructures.response_containers import (
     File,
     Redirect,
@@ -62,6 +62,7 @@ from starlite.utils.sync import AsyncCallable
 if TYPE_CHECKING:
     from starlite.app import Starlite
     from starlite.connection import Request
+    from starlite.datastructures.headers import Header
     from starlite.plugins import PluginProtocol
     from starlite.types import AnyCallable, AsyncAnyCallable
 
@@ -218,11 +219,13 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         "background",
         "before_request",
         "cache",
+        "cache_control",
         "cache_key_builder",
         "content_encoding",
         "content_media_type",
         "deprecated",
         "description",
+        "etag",
         "http_method",
         "include_in_schema",
         "media_type",
@@ -251,8 +254,10 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         background: Optional[Union[BackgroundTask, BackgroundTasks]] = None,
         before_request: Optional[BeforeRequestHookHandler] = None,
         cache: Union[bool, int] = False,
+        cache_control: Optional[CacheControlHeader] = None,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
+        etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         http_method: Union[HttpMethod, Method, List[Union[HttpMethod, Method]]],
@@ -299,9 +304,12 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
                 bypassing the route handler.
             cache: Enables response caching if configured on the application level. Valid values are 'true' or a number
                 of seconds (e.g. '120') to cache the response.
+            cache_control: A `cache-control` header of type
+                [CacheControlHeader][starlite.datastructures.CacheControlHeader] that will be added to the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
             dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            etag: An `etag` header of type [ETag][starlite.datastructures.ETag] that will be added to the response.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             http_method: An [http method string][starlite.types.Method], a member of the enum
@@ -367,7 +375,9 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         self.background = background
         self.before_request = AsyncCallable(before_request) if before_request else None
         self.cache = cache
+        self.cache_control = cache_control
         self.cache_key_builder = cache_key_builder
+        self.etag = etag
         self.media_type = media_type
         self.response_class = response_class
         self.response_cookies = response_cookies
@@ -420,6 +430,17 @@ class HTTPRouteHandler(BaseRouteHandler["HTTPRouteHandler"]):
         resolved_response_headers = {}
         for layer in self.ownership_layers:
             resolved_response_headers.update(layer.response_headers or {})
+            for extra_header in ("cache_control", "etag"):
+                header_model: Optional["Header"] = getattr(layer, extra_header, None)
+                if header_model:
+                    resolved_response_headers.update(
+                        {
+                            header_model.HEADER_NAME: ResponseHeader(
+                                value=header_model.to_header(), documentation_only=header_model.documentation_only
+                            )
+                        }
+                    )
+
         return resolved_response_headers
 
     def resolve_response_cookies(self) -> "ResponseCookies":
@@ -608,8 +629,10 @@ class get(HTTPRouteHandler):
         background: Optional[Union[BackgroundTask, BackgroundTasks]] = None,
         before_request: Optional[BeforeRequestHookHandler] = None,
         cache: Union[bool, int] = False,
+        cache_control: Optional[CacheControlHeader] = None,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
+        etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
@@ -655,6 +678,8 @@ class get(HTTPRouteHandler):
                 bypassing the route handler.
             cache: Enables response caching if configured on the application level. Valid values are 'true' or a number
                 of seconds (e.g. '120') to cache the response.
+            cache_control: A `cache-control` header of type
+                [CacheControlHeader][starlite.datastructures.CacheControlHeader] that will be added to the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
             dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
@@ -697,12 +722,14 @@ class get(HTTPRouteHandler):
             background=background,
             before_request=before_request,
             cache=cache,
+            cache_control=cache_control,
             cache_key_builder=cache_key_builder,
             content_encoding=content_encoding,
             content_media_type=content_media_type,
             dependencies=dependencies,
             deprecated=deprecated,
             description=description,
+            etag=etag,
             exception_handlers=exception_handlers,
             guards=guards,
             http_method=HttpMethod.GET,
@@ -739,8 +766,10 @@ class post(HTTPRouteHandler):
         background: Optional[Union[BackgroundTask, BackgroundTasks]] = None,
         before_request: Optional[BeforeRequestHookHandler] = None,
         cache: Union[bool, int] = False,
+        cache_control: Optional[CacheControlHeader] = None,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
+        etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
@@ -786,9 +815,12 @@ class post(HTTPRouteHandler):
                 bypassing the route handler.
             cache: Enables response caching if configured on the application level. Valid values are 'true' or a number
                 of seconds (e.g. '120') to cache the response.
+            cache_control: A `cache-control` header of type
+                [CacheControlHeader][starlite.datastructures.CacheControlHeader] that will be added to the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
             dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            etag: An `etag` header of type [ETag][starlite.datastructures.ETag] that will be added to the response.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
@@ -827,6 +859,7 @@ class post(HTTPRouteHandler):
             background=background,
             before_request=before_request,
             cache=cache,
+            cache_control=cache_control,
             cache_key_builder=cache_key_builder,
             content_encoding=content_encoding,
             content_media_type=content_media_type,
@@ -834,6 +867,7 @@ class post(HTTPRouteHandler):
             deprecated=deprecated,
             description=description,
             exception_handlers=exception_handlers,
+            etag=etag,
             guards=guards,
             http_method=HttpMethod.POST,
             include_in_schema=include_in_schema,
@@ -869,8 +903,10 @@ class put(HTTPRouteHandler):
         background: Optional[Union[BackgroundTask, BackgroundTasks]] = None,
         before_request: Optional[BeforeRequestHookHandler] = None,
         cache: Union[bool, int] = False,
+        cache_control: Optional[CacheControlHeader] = None,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
+        etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
@@ -916,9 +952,12 @@ class put(HTTPRouteHandler):
                 bypassing the route handler.
             cache: Enables response caching if configured on the application level. Valid values are 'true' or a number
                 of seconds (e.g. '120') to cache the response.
+            cache_control: A `cache-control` header of type
+                [CacheControlHeader][starlite.datastructures.CacheControlHeader] that will be added to the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
             dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            etag: An `etag` header of type [ETag][starlite.datastructures.ETag] that will be added to the response.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
@@ -942,7 +981,9 @@ class put(HTTPRouteHandler):
             description: Text used for the route's schema description section.
             include_in_schema: A boolean flag dictating whether  the route handler should be documented in the OpenAPI schema.
             operation_id: An identifier used for the route's schema operationId. Defaults to the __name__ of the wrapped function.
-            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation. This list should describe all exceptions raised within the route handler's function/method. The Starlite ValidationException will be added automatically for the schema if any validation is involved.
+            raises:  A list of exception classes extending from starlite.HttpException that is used for the OpenAPI documentation.
+                This list should describe all exceptions raised within the route handler's function/method. T
+                he Starlite ValidationException will be added automatically for the schema if any validation is involved.
             response_description: Text used for the route's response schema description section.
             security: A list of dictionaries that contain information about which security scheme can be used on the endpoint.
             summary: Text used for the route's schema summary section.
@@ -957,6 +998,7 @@ class put(HTTPRouteHandler):
             background=background,
             before_request=before_request,
             cache=cache,
+            cache_control=cache_control,
             cache_key_builder=cache_key_builder,
             content_encoding=content_encoding,
             content_media_type=content_media_type,
@@ -964,6 +1006,7 @@ class put(HTTPRouteHandler):
             deprecated=deprecated,
             description=description,
             exception_handlers=exception_handlers,
+            etag=etag,
             guards=guards,
             http_method=HttpMethod.PUT,
             include_in_schema=include_in_schema,
@@ -999,8 +1042,10 @@ class patch(HTTPRouteHandler):
         background: Optional[Union[BackgroundTask, BackgroundTasks]] = None,
         before_request: Optional[BeforeRequestHookHandler] = None,
         cache: Union[bool, int] = False,
+        cache_control: Optional[CacheControlHeader] = None,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
+        etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
@@ -1046,9 +1091,12 @@ class patch(HTTPRouteHandler):
                 bypassing the route handler.
             cache: Enables response caching if configured on the application level. Valid values are 'true' or a number
                 of seconds (e.g. '120') to cache the response.
+            cache_control: A `cache-control` header of type
+                [CacheControlHeader][starlite.datastructures.CacheControlHeader] that will be added to the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
             dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            etag: An `etag` header of type [ETag][starlite.datastructures.ETag] that will be added to the response.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
@@ -1087,12 +1135,14 @@ class patch(HTTPRouteHandler):
             background=background,
             before_request=before_request,
             cache=cache,
+            cache_control=cache_control,
             cache_key_builder=cache_key_builder,
             content_encoding=content_encoding,
             content_media_type=content_media_type,
             dependencies=dependencies,
             deprecated=deprecated,
             description=description,
+            etag=etag,
             exception_handlers=exception_handlers,
             guards=guards,
             http_method=HttpMethod.PATCH,
@@ -1129,8 +1179,10 @@ class delete(HTTPRouteHandler):
         background: Optional[Union[BackgroundTask, BackgroundTasks]] = None,
         before_request: Optional[BeforeRequestHookHandler] = None,
         cache: Union[bool, int] = False,
+        cache_control: Optional[CacheControlHeader] = None,
         cache_key_builder: Optional[CacheKeyBuilder] = None,
         dependencies: Optional[Dict[str, Provide]] = None,
+        etag: Optional[ETag] = None,
         exception_handlers: Optional[ExceptionHandlersMap] = None,
         guards: Optional[List[Guard]] = None,
         media_type: Union[MediaType, str] = MediaType.JSON,
@@ -1176,9 +1228,12 @@ class delete(HTTPRouteHandler):
                 bypassing the route handler.
             cache: Enables response caching if configured on the application level. Valid values are 'true' or a number
                 of seconds (e.g. '120') to cache the response.
+            cache_control: A `cache-control` header of type
+                [CacheControlHeader][starlite.datastructures.CacheControlHeader] that will be added to the response.
             cache_key_builder: A [cache-key builder function][starlite.types.CacheKeyBuilder]. Allows for customization
                 of the cache key if caching is configured on the application level.
             dependencies: A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances.
+            etag: An `etag` header of type [ETag][starlite.datastructures.ETag] that will be added to the response.
             exception_handlers: A dictionary that maps handler functions to status codes and/or exception types.
             guards: A list of [Guard][starlite.types.Guard] callables.
             media_type: A member of the [MediaType][starlite.enums.MediaType] enum or a string with a
@@ -1217,12 +1272,14 @@ class delete(HTTPRouteHandler):
             background=background,
             before_request=before_request,
             cache=cache,
+            cache_control=cache_control,
             cache_key_builder=cache_key_builder,
             content_encoding=content_encoding,
             content_media_type=content_media_type,
             dependencies=dependencies,
             deprecated=deprecated,
             description=description,
+            etag=etag,
             exception_handlers=exception_handlers,
             guards=guards,
             http_method=HttpMethod.DELETE,
